package com.wd.workoffice.presenter;

import com.alibaba.fastjson.JSON;
import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.bean.ContactsBean;
import com.wd.workoffice.bean.ContactsList;
import com.wd.workoffice.contract.WorkContactsContract;
import com.wd.workoffice.model.WorkContactsModel;
import com.wd.workoffice.retrofit.WorkObserver;

import java.util.Map;

import flexible.xd.android_base.mvpBase.BasePresenter;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;

/**
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkContactsPresenter  extends BasePresenter<WorkContactsContract.View, WorkContactsContract.Model> implements WorkContactsContract.Presenter {
    @Override
    public void getData(Map<String, Object> param) {
        mView.showLoading();
        mModel.getData(param).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
                mDisposable.add(d);
            }

            @Override
            public void onFail(String errorMsg) {
                mView.hideLoading();
                mView.onError(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                mView.hideLoading();
                if (data.getCode() != 0) {
                    mView.onError(data.getMessage());
                    return;
                }
                mView.getData(JSON.parseArray(JSON.parseObject(data.getData().toString()).getString("records"), ContactsBean.class));
            }
        });
    }

    @Override
    public WorkContactsContract.Model bindModel() {
        return WorkContactsModel.newInstance();
    }

}
