package com.wd.workoffice.presenter;

import com.alibaba.fastjson.JSON;
import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.bean.ProductBean;
import com.wd.workoffice.bean.WarehouseOrderBean;
import com.wd.workoffice.bean.WarehoustBean;
import com.wd.workoffice.contract.WorkWarehouseContract;
import com.wd.workoffice.model.WorkWarehouseModel;
import com.wd.workoffice.retrofit.WorkObserver;

import java.util.Map;

import flexible.xd.android_base.mvpBase.BasePresenter;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;

/**
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkWarehousePresenter extends BasePresenter<WorkWarehouseContract.View, WorkWarehouseContract.Model> implements WorkWarehouseContract.Presenter {
    @Override
    public void getWarehouse(Map<String, Object> param) {
        mView.showLoading();
        mModel.getWarehouse(param).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
                mDisposable.add(d);
            }

            @Override
            public void onFail(String errorMsg) {
                mView.hideLoading();
                mView.onError(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                mView.hideLoading();
                if (data.getCode() != 0) {
                    mView.onError(data.getMessage());
                    return;
                }
                mView.getWarehouse(JSON.parseObject(data.getData().toString(), WarehoustBean.class).getRecords());
            }
        });
    }

    @Override
    public void getOrder(Map<String, Object> param) {
        mView.showLoading();
        mModel.getOrder(param).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
                mDisposable.add(d);
            }

            @Override
            public void onFail(String errorMsg) {
                mView.hideLoading();
                mView.onError(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                mView.hideLoading();
                if (data.getCode() != 0) {
                    mView.onError(data.getMessage());
                    return;
                }
                mView.getOrder(JSON.parseObject(data.getData().toString(), WarehouseOrderBean.class).getRecords());
            }
        });
    }

    @Override
    public WorkWarehouseContract.Model bindModel() {
        return WorkWarehouseModel.newInstance();
    }
}
