package com.wd.workoffice.ui.activity.mes.user;

import android.content.Intent;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import com.alibaba.fastjson.JSON;
import com.chad.library.adapter.base.BaseQuickAdapter;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseMesBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.event.AddUserDataEvent;
import com.wd.workoffice.bean.mesBean.MesClientBean;
import com.wd.workoffice.bean.mesBean.UserDataBean;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.adapter.UserDataClientAdapter;
import com.wd.workoffice.util.WorkUtils;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;

/**
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class MesChooseClientActivity extends WorkToolBarActivity {

    @BindView(R.id.et_key)
    EditText etKey;
    @BindView(R.id.btn_search)
    Button btnSearch;
    @BindView(R.id.rv_client)
    RecyclerView rvClient;
    private Map<String, Object> param;
    private List<MesClientBean.ListBean> clientList;
    private UserDataClientAdapter clientAdapter;
    private int page = 1;
    private Map<String, Object> paramMap;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        rvClient.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));
    }

    @Override
    protected void initData() {
        clientList = new ArrayList<>();
        clientAdapter = new UserDataClientAdapter(R.layout.item_user_data_client, clientList);
        clientAdapter.bindToRecyclerView(rvClient);
        clientAdapter.setEmptyView(R.layout.view_empty_content, rvClient);
        param = WorkUtils.pageMesKey();
        paramMap = WorkUtils.simpleParam();
        param.put("pageNum", 1);
        param.put("paramMap",paramMap);
        getData();
    }

    private void getData() {
        RtfUtils.getMesRtf().clientList("1", WorkUtils.convertMapToBody(param)).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseMesBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseMesBean data) {
                hideLoading();
                if (!data.isSuccess()) {
                    toast(data.getMessage());
                    return;
                }
                List<MesClientBean.ListBean> getList = JSON.parseObject(data.getData().toString(), MesClientBean.class).getList();
                if (page == 1) {
                    clientList.clear();
                    clientList.addAll(getList);
                    clientAdapter.notifyDataSetChanged();
                    clientAdapter.loadMoreComplete();
                } else {
                    clientAdapter.loadMoreComplete();
                    clientList.addAll(getList);
                    clientAdapter.notifyDataSetChanged();
                }
                if (getList.size() == 0) {
                    clientAdapter.loadMoreEnd();
                } else {
                    page++;
                }
                toast("搜索成功");
            }
        });
    }

    @Override
    protected void initEvent() {
        clientAdapter.setOnLoadMoreListener(new BaseQuickAdapter.RequestLoadMoreListener() {
            @Override
            public void onLoadMoreRequested() {
                param.put("pageNum", page);
                getData();
            }
        }, rvClient);
        clientAdapter.setOnItemClickListener(new BaseQuickAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(BaseQuickAdapter adapter, View view, int position) {
                MesClientBean.ListBean chooseClient = clientList.get(position);
                if (TextUtils.equals("1",getIntent().getStringExtra("from"))){// 新增连铸机供应商
                        Intent intent =new Intent();
                        intent.putExtra("data",JSON.toJSONString(chooseClient));
                        setResult(10001,intent);
                        finish();
                }else{
                    UserDataBean.ListBean userDataBean = new UserDataBean.ListBean();
                    userDataBean.setCustomerUserCode(chooseClient.getCustomerCode());
                    userDataBean.setCustomerUserName(chooseClient.getCustomerName());
                    userDataBean.setSalesCompanyCode(chooseClient.getSalesCompanyCode());
                    userDataBean.setSalesCompanyName(chooseClient.getSalesCompanyName());
                    userDataBean.setSalesManagerCode(chooseClient.getSalesManagerCode());
                    userDataBean.setSalesManagerName(chooseClient.getSalesManagerName());
                    startActivity(MesUserDataAdd2Activity.class, "data", JSON.toJSONString(userDataBean));
                }
            }
        });
    }

    @Override
    protected int layoutId() {
        return R.layout.activity_bat_sale_client;
    }


    @OnClick(R.id.btn_search)
    public void onViewClicked() {
        paramMap.put("customerName", etKey.getText().toString());
        param.put("pageNum", 1);
        page = 1;
        getData();
    }

    @Override
    public void onStart() {
        super.onStart();
        EventBus.getDefault().register(this);
    }

    @Override
    public void onStop() {
        super.onStop();
        EventBus.getDefault().unregister(this);
    }

    @Subscribe
    public void refresh(AddUserDataEvent event) {
        finish();
    }
}